@@ -1,21 +1,19 @@
 package Exporter::Lite;
 
-require 5.004;
-
-# Using strict or vars almost doubles our load time.  Turn them back
-# on when debugging.
-#use strict 'vars';  # we're going to be doing a lot of sym refs
-#use vars qw($VERSION @EXPORT);
-
-$VERSION = 0.02;
-@EXPORT = qw(import);   # we'll know pretty fast if it doesn't work :)
+require 5.006;
+use warnings;
+use strict;
 
+our $VERSION = '0.03';
+our @EXPORT = qw(import);
 
 
 sub import {
     my($exporter, @imports)  = @_;
     my($caller, $file, $line) = caller;
 
+    no strict 'refs';
+
     unless( @imports ) {        # Default import.
         @imports = @{$exporter.'::EXPORT'};
     }
@@ -49,6 +47,8 @@ sub import {
 sub _export {
     my($caller, $exporter, @imports) = @_;
 
+    no strict 'refs';
+
     # Stole this from Exporter::Heavy.  I'm sure it can be written better
     # but I'm lazy at the moment.
     foreach my $sym (@imports) {
@@ -132,7 +132,7 @@ You have to ask for them.  C<use My::Module qw($Foo bar)>.
 =head1 Methods
 
 Export::Lite has one public method, import(), which is called
-automaticly when your modules is use()'d.  
+automatically when your modules is use()'d.  
 
 In normal usage you don't have to worry about this at all.
 
@@ -178,6 +178,33 @@ Exporter.  I know its at least on par.
 OTOH, the docs are much clearer and not having to say C<@ISA =
 qw(Exporter)> is kinda nice.
 
+=head1 SEE ALSO
+
+L<Exporter> is the grandaddy of all Exporter module, and bundled with Perl
+itself, unlike the rest of the modules listed here.
+
+L<Attribute::Exporter> defines attributes which you use to mark
+which subs and variables you want to export, and how.
+
+L<Exporter::Simple> also uses attributes to control the export of
+functions and variables from your module.
+
+L<Const::Exporter> makes it easy to create a module that exports constants.
+
+L<Constant::Exporter> is another module that makes it easy to create
+modules that define and export constants.
+
+L<Exporter::Auto> will export everything from your module that
+it thinks is a public function (name doesn't start with an underscore).
+
+L<Class::Exporter> lets you export class methods as regular subroutines.
+
+L<Xporter> is like Exporter, but with persistent defaults and auto-ISA.
+
+=head1 REPOSITORY
+
+L<https://github.com/neilbowers/Exporter-Lite>
+
 =head1 AUTHORS
 
 Michael G Schwern <schwern@pobox.com>
@@ -189,8 +216,4 @@ modify it under the same terms as Perl itself.
 
 See F<http://www.perl.com/perl/misc/Artistic.html>
 
-=head1 SEE ALSO
-
-L<Exporter>, L<Exporter::Simple>, L<UNIVERSAL::exports>
-
 =cut
